import { normalizeParams } from './binlib';

describe('Normalizing input variables', () => {
  it('is works on empty param list', () => {
    expect(normalizeParams([])).toEqual([]);
  });

  it('handles standard cases', () => {
    expect(normalizeParams(['aaa=bbb', 'ccc=ddd'])).toEqual(['aaa=bbb', 'ccc=ddd']);
    expect(normalizeParams(['aaa =bbb', 'ccc= ddd', 'eee = fff'])).toEqual(['aaa=bbb', 'ccc=" ddd"', 'eee=" fff"']);
  });

  it('joins', () => {
    expect(normalizeParams(['aaa', '=', 'bbb', 'ccc', '=', 'ddd'])).toEqual(['aaa=bbb', 'ccc=ddd']);
  });

  it('not alow empty props when escaped', () => {
    expect(() => normalizeParams(['aaa', '='])).toThrowError(/Invalid argument/);
  });

  it('allow empty props when properly formatted', () => {
    expect(normalizeParams(['aaa='])).toEqual(['aaa=']);
  });

  it('escapes strings with spaces or double quotes', () => {
    expect(normalizeParams(['aaa=ala ma kota', 'ccc="ddd'])).toEqual(['aaa=\"ala ma kota\"', 'ccc=\"\\\"ddd\"']);
  });
});
